Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(616)

Unified Diff: Source/core/css/DOMWindowCSS.cpp

Issue 566703002: Revert of Split out CSSParser public API (Closed) Base URL: https://chromium.googlesource.com/chromium/blink.git@master
Patch Set: Created 6 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « Source/core/css/CSSValuePool.cpp ('k') | Source/core/css/FontFace.cpp » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: Source/core/css/DOMWindowCSS.cpp
diff --git a/Source/core/css/DOMWindowCSS.cpp b/Source/core/css/DOMWindowCSS.cpp
index 0bf59f9275cbcf72dbc764b98f2d8261bd3d06b4..2ce5c959a306adcaadd529ce1ca2305bff1a29b6 100644
--- a/Source/core/css/DOMWindowCSS.cpp
+++ b/Source/core/css/DOMWindowCSS.cpp
@@ -32,7 +32,7 @@
#include "core/css/CSSPropertyMetadata.h"
#include "core/css/StylePropertySet.h"
-#include "core/css/parser/CSSParser.h"
+#include "core/css/parser/BisonCSSParser.h"
#include "wtf/text/WTFString.h"
namespace blink {
@@ -63,7 +63,7 @@
return false;
ASSERT(CSSPropertyMetadata::isEnabledProperty(propertyID));
// CSSParser::parseValue() won't work correctly if !important is present,
// so just get rid of it. It doesn't matter to supports() if it's actually
// there or not, provided how it's specified in the value is correct.
String normalizedValue = value.stripWhiteSpace().simplifyWhiteSpace();
@@ -73,12 +73,14 @@
return false;
RefPtrWillBeRawPtr<MutableStylePropertySet> dummyStyle = MutableStylePropertySet::create();
- return CSSParser::parseValue(dummyStyle.get(), propertyID, normalizedValue, false, HTMLStandardMode, 0);
+ return BisonCSSParser::parseValue(dummyStyle.get(), propertyID, normalizedValue, false, HTMLStandardMode, 0);
}
bool DOMWindowCSS::supports(const String& conditionText) const
{
- return CSSParser::parseSupportsCondition(conditionText);
+ CSSParserContext context(HTMLStandardMode, 0);
+ BisonCSSParser parser(context);
+ return parser.parseSupportsCondition(conditionText);
}
}
« no previous file with comments | « Source/core/css/CSSValuePool.cpp ('k') | Source/core/css/FontFace.cpp » ('j') | no next file with comments »
@@ -63,7 +63,7 @@
return false;
ASSERT(CSSPropertyMetadata::isEnabledProperty(propertyID));
- // CSSParser::parseValue() won't work correctly if !important is present,
+ // BisonCSSParser::parseValue() won't work correctly if !important is present,
// so just get rid of it. It doesn't matter to supports() if it's actually
// there or not, provided how it's specified in the value is correct.

Powered by Google App Engine
This is Rietveld 408576698